import 'package:event_bus/event_bus.dart';
import 'package:flutter/material.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_friend_info.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_value_callback.dart';
import 'package:tencent_im_sdk_plugin/tencent_im_sdk_plugin.dart';
import 'package:tencent_im_sdk_plugin_example/common/avatar.dart';
import 'package:tencent_im_sdk_plugin_example/common/colors.dart';
import 'package:tencent_im_sdk_plugin_example/common/hexToColor.dart';
import 'package:tencent_im_sdk_plugin_example/pages/conversion/conversion.dart';

EventBus eventBus = new EventBus();

class ChooseContact extends StatefulWidget {
  @override
  State<StatefulWidget> createState() => ChooseContactState();
}

class FriendItem extends StatefulWidget {
  V2TimFriendInfo info;
  FriendItem(V2TimFriendInfo info) {
    this.info = info;
  }
  @override
  State<StatefulWidget> createState() => FriendItemState(info);
}

class FriendItemState extends State<FriendItem> {
  V2TimFriendInfo info;
  FriendItemState(this.info);
  String checkValue;
  getUserShowName() {
    return info.friendRemark == null || info.friendRemark == ''
        ? info.userID
        : info.friendRemark;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      height: 50,
      decoration: BoxDecoration(
        color: CommonColors.getWitheColor(),
        border: Border(
          bottom: BorderSide(
            width: 1,
            color: CommonColors.getBorderColor(),
            style: BorderStyle.solid,
          ),
        ),
      ),
      child: Row(
        children: [
          Radio(
            value: info.userID,
            groupValue: checkValue,
            onChanged: (s) {
              setState(() {
                checkValue = s;
              });
              eventBus.fire(
                new TransEvent(
                  info.userID,
                  s == null ? 'decrease' : 'increase',
                ),
              );
            },
            toggleable: true,
          ),
          Container(
            width: 30,
            height: 30,
            child: Avatar(
              width: 30,
              height: 30,
              radius: 0,
              avtarUrl: 'images/person.png',
            ),
          ),
          Padding(
            padding: EdgeInsets.only(left: 10),
            child: Text(getUserShowName()),
          )
        ],
      ),
    );
  }
}

class TransEvent {
  String id;
  String action; // 0
  TransEvent(this.id, this.action);
}

class ChooseContactState extends State<ChooseContact> {
  List<V2TimFriendInfo> list = [];

  Map<String, String> selectMap = new Map();
  ChooseContactState() {
    getFriendList();
    eventBus
        .on<TransEvent>()
        .listen((TransEvent data) => selectListChange(data.id, data.action));
  }
  selectListChange(id, action) {
    // print('${action}${id}');
    setState(() {
      if (action == 'increase') {
        selectMap[id] = id;
      } else {
        selectMap.remove(id);
      }
      // print(selectMap.values.toList());
    });
  }

  getFriendList() async {
    V2TimValueCallback<List<V2TimFriendInfo>> data = await tencent_im_sdk_plugin
        .v2TIMManager
        .getFriendshipManager()
        .getFriendList();
    if (data.code == 0) {
      print(data.data[0].toJson());
      this.setState(() {
        list = data.data;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("选择联系人"),
        backgroundColor: CommonColors.getThemeColor(),
      ),
      body: Container(
        color: CommonColors.getGapColor(),
        child: Column(
          children: [
            Expanded(
              child: ListView(
                children: list.map((e) => FriendItem(e)).toList(),
              ),
            ),
            Container(
              height: 50,
              color: hexToColor('000000'),
              child: Row(
                children: [
                  Expanded(
                    child: Container(
                      child: Text(''),
                    ),
                  ),
                  Padding(
                    padding: EdgeInsets.only(right: 10),
                    child: FlatButton(
                      child: Text("确定"),
                      textColor: hexToColor('ffffff'),
                      disabledColor: CommonColors.getGapColor(),
                      disabledTextColor: hexToColor('000000'),
                      color: CommonColors.getThemeColor(),
                      onPressed: selectMap.isEmpty
                          ? null
                          : () {
                              Navigator.pushReplacement(
                                context,
                                new MaterialPageRoute(
                                  builder: (context) => Conversion(
                                      'c2c_${selectMap.values.toList()[0]}'),
                                ),
                              );
                            },
                    ),
                  )
                ],
              ),
            )
          ],
        ),
      ),
    );
  }
}
