import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_message.dart';
import 'package:tencent_im_sdk_plugin/tencent_im_sdk_plugin.dart';
import 'package:tencent_im_sdk_plugin_example/common/colors.dart';
import 'package:tencent_im_sdk_plugin_example/pages/conversion/component/msgInput.dart';
import 'package:tencent_im_sdk_plugin_example/pages/conversion/component/sendMsg.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_value_callback.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_conversation.dart';
import 'package:tencent_im_sdk_plugin_example/provider/currentMessageList.dart';

class Conversion extends StatefulWidget {
  String conversationID;
  Conversion(conversationID) {
    this.conversationID = conversationID;
  }
  @override
  State<StatefulWidget> createState() => ConversionState(conversationID);
}

class ConversionState extends State<Conversion> {
  String conversationID;
  int type = 0;
  String lastMessageId = '';
  String userID = '';
  String groupID = '';
  List<V2TimMessage> msgList = [];
  ScrollController scrollController = new ScrollController();
  ConversionState(conversationID) {
    this.conversationID = conversationID;
    getConversion();
  }

  Icon righTopIcon = false
      ? Icon(
          Icons.supervisor_account,
          color: CommonColors.getWitheColor(),
        )
      : Icon(
          Icons.account_box,
          color: CommonColors.getWitheColor(),
        );
  openProfile(context) {
    print(223);
    // Navigator.push(
    //   context,
    //   new MaterialPageRoute(
    //     builder: (context) => Conversion(),
    //   ),
    // );
  }

  getConversion() async {
    V2TimValueCallback<V2TimConversation> data = await tencent_im_sdk_plugin
        .v2TIMManager
        .getConversationManager()
        .getConversation(conversationID: conversationID);
    String _msgID;
    int _type;
    String _groupID;
    String _userID;

    if (data.code == 0) {
      _msgID = data.data.lastMessage.msgID;
      _type = data.data.type;
      _groupID = data.data.groupID;
      _userID = data.data.userID;
      print(_type);
      print('_userID${_userID}');
      print('_groupID${_groupID}');
      setState(() {
        type = _type;
        lastMessageId = _msgID;
        groupID = _groupID;
        userID = _userID;
      });
    }
    //判断会话类型，c2c or group
    V2TimValueCallback<List<V2TimMessage>> listRes;
    if (_type == 1) {
      // c2c
      listRes = await tencent_im_sdk_plugin.v2TIMManager
          .getMessageManager()
          .getC2CHistoryMessageList(
            userID: _userID,
            count: 10,
          );
      await tencent_im_sdk_plugin.v2TIMManager
          .getMessageManager()
          .markC2CMessageAsRead(userID: _userID);
    } else if (_type == 2) {
      // group
      listRes = await tencent_im_sdk_plugin.v2TIMManager
          .getMessageManager()
          .getGroupHistoryMessageList(
            groupID: _groupID,
            count: 10,
          );
      var data = await tencent_im_sdk_plugin.v2TIMManager
          .getMessageManager()
          .markGroupMessageAsRead(groupID: _groupID);
      print('设置已读${data.code}');
    }
    if (listRes.code == 0) {
      List<V2TimMessage> list = listRes.data;
      if (list == null || list.length == 0) {
        print('没有消息啊！！！');
        List<V2TimMessage> newList = [];
        Provider.of<CurrentMessageListModel>(context, listen: false)
            .setCurrentMessageList(newList);
        return;
      }
      list.sort((left, right) => left.timestamp.compareTo(right.timestamp));
      Provider.of<CurrentMessageListModel>(context, listen: false)
          .setCurrentMessageList(list);
    } else {
      print('获取历史消息失败');
    }
  }

  @override
  Widget build(BuildContext context) {
    List<V2TimMessage> currentMessageList =
        Provider.of<CurrentMessageListModel>(context).msgList;
    return Scaffold(
      appBar: AppBar(
        title: Text("会话"),
        actions: [
          IconButton(
            icon: righTopIcon,
            onPressed: () {
              openProfile(context);
            },
          )
        ],
      ),
      body: Column(
        children: [
          Expanded(
            child: Container(
              color: Colors.white,
              child: SingleChildScrollView(
                controller: scrollController,
                padding: EdgeInsets.fromLTRB(12, 0, 12, 0),
                child: Column(
                  children: (currentMessageList == null ||
                          currentMessageList.length == 0)
                      ? [Container()]
                      : currentMessageList
                          .map(
                            (e) => SendMsg(
                              type: e.isSelf ? 1 : 2,
                              name: (e.nickName == null || e.nickName == '')
                                  ? e.sender
                                  : e.nickName,
                              message: e.elemType == 1
                                  ? '${e.textElem.text}'
                                  : '${e.elemType}',
                            ),
                          )
                          .toList(),
                ),
              ),
            ),
          ),
          type == 0 ? Container() : MsgInput(type == 1 ? userID : groupID, type)
        ],
      ),
    );
  }
}
