import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:tencent_im_sdk_plugin/tencent_im_sdk_plugin.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_conversation_result.dart';
import 'package:tencent_im_sdk_plugin_example/pages/conversion/conversion.dart';
import 'package:tencent_im_sdk_plugin_example/provider/conversion.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_value_callback.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_conversation.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_message.dart';
// class ConversionItem extends StatelessWidget {
//   String conversionIcon = '';
//   String conversionName = '';
//   ConversionItem({
//     Key key,
//     this.conversionIcon,
//     this.conversionName
//   }) : super(key: key);
//   Widget build(BuildContext context) {
//     return Container(
//       height: 60,
//       color: Colors.amber[500],
//       child: const Center(child: Text("")),
//     );
//   }
// }

class Message extends StatefulWidget {
  State<StatefulWidget> createState() => MessageState();
}

class MessageState extends State<Message> {
  MessageState() {
    getMessage();
  }
  var conversionList;
  getMessage() async {
    V2TimValueCallback<V2TimConversationResult> data =
        await tencent_im_sdk_plugin.v2TIMManager
            .getConversationManager()
            .getConversationList(count: 10, nextSeq: 0);

    context
        .read<ConversionModel>()
        .setConversionList(data.data.conversationList);
  }

  Widget build(BuildContext context) {
    List<V2TimConversation> list =
        context.watch<ConversionModel>().conversionList;
    if (list == null || list.isEmpty) {
      return Container();
    }
    list.sort((left, right) =>
        right.lastMessage.timestamp.compareTo(left.lastMessage.timestamp));

    return ListView(
      children: list.map((e) {
        if (e.lastMessage.msgID == '') {
          return Container();
        }

        return new ConversionItem(
          name: e.showName,
          faceUrl: e.faceUrl,
          lastMessage: e.lastMessage,
          unreadCount: e.unreadCount,
          type: e.type,
          conversationID: e.conversationID,
          userID: e.userID,
        );
      }).toList(),
    );
  }
}

class ConversionItem extends StatelessWidget {
  String name = '';
  String faceUrl = '';
  V2TimMessage lastMessage;
  int unreadCount = 0;
  int type = 0;
  String conversationID = '';
  String userID = '';
  ConversionItem({
    this.name,
    this.faceUrl,
    this.lastMessage,
    this.unreadCount,
    this.type,
    this.conversationID,
    this.userID,
  });
  test1(context) {
    Navigator.push(
      context,
      new MaterialPageRoute(
        builder: (context) => Conversion(conversationID),
      ),
    );
  }

  String formatTime() {
    int timestamp = lastMessage.timestamp * 1000;
    DateTime time = DateTime.fromMillisecondsSinceEpoch(timestamp);
    DateTime now = DateTime.now();

    if (now.millisecondsSinceEpoch > time.millisecondsSinceEpoch) {
      return "${time.month.toString().padLeft(2, '0')}-${time.day.toString().padLeft(2, '0')}";
    } else if (now.day == time.day) {
      return "${time.hour.toString().padLeft(2, '0')}:${time.minute.toString().padLeft(2, '0')}:${time.second.toString().padLeft(2, '0')}";
    }
  }

  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () => {test1(context)},
      child: Container(
        height: 70,
        child: Row(
          children: [
            Container(
              width: 70,
              height: 70,
              child: Padding(
                padding: EdgeInsets.all(11),
                child: PhysicalModel(
                  color: Colors.transparent,
                  borderRadius: BorderRadius.circular(4.8),
                  clipBehavior: Clip.antiAlias,
                  child: Image(
                    image: type == 1
                        ? AssetImage('images/person.png')
                        : AssetImage('images/logo.png'),
                    width: 48,
                    height: 48,
                  ),
                ),
              ),
            ),
            Expanded(
              child: Container(
                height: 70,
                decoration: BoxDecoration(
                  border: Border(
                    bottom: BorderSide(
                      color:
                          Color(int.parse('ededed', radix: 16)).withAlpha(255),
                      width: 1,
                      style: BorderStyle.solid,
                    ),
                  ),
                ),
                child: Column(
                  children: [
                    Container(
                      height: 24,
                      margin: EdgeInsets.only(top: 11),
                      child: Row(
                        children: [
                          Expanded(
                            child: Text(
                              name == null ? "xx" : name,
                              style: TextStyle(
                                color: Color(int.parse('111111', radix: 16))
                                    .withAlpha(255),
                                fontSize: 18,
                                height: 1,
                              ),
                              textAlign: TextAlign.left,
                              maxLines: 1,
                              overflow: TextOverflow.ellipsis,
                            ),
                          ),
                          Container(
                            child: Text(
                              formatTime(),
                              textAlign: TextAlign.right,
                              style: TextStyle(
                                  color: Color(int.parse('b0b0b0', radix: 16))
                                      .withAlpha(255),
                                  fontSize: 12),
                            ),
                            width: 105,
                            padding: EdgeInsets.only(right: 16),
                          )
                        ],
                      ),
                    ),
                    Container(
                      height: 20,
                      margin: EdgeInsets.only(top: 2),
                      child: Row(
                        children: [
                          Expanded(
                              child: Text(
                            lastMessage.elemType == 1
                                ? lastMessage.textElem == null
                                    ? ''
                                    : lastMessage.textElem.text
                                : lastMessage.elemType == 9
                                    ? '群系统消息'
                                    : '',
                            style: TextStyle(
                              color: Color(int.parse('999999', radix: 16))
                                  .withAlpha(255),
                              fontSize: 14,
                            ),
                          )),
                          Container(
                            child: unreadCount > 0
                                ? PhysicalModel(
                                    color: Colors.transparent,
                                    borderRadius: BorderRadius.circular(9),
                                    clipBehavior: Clip.antiAlias,
                                    child: Container(
                                      color:
                                          Color(int.parse('FA5151', radix: 16))
                                              .withAlpha(255),
                                      width: 18,
                                      height: 18,
                                      child: Column(
                                        mainAxisAlignment:
                                            MainAxisAlignment.center,
                                        crossAxisAlignment:
                                            CrossAxisAlignment.center,
                                        children: [
                                          Text(
                                            unreadCount > 99
                                                ? '...'
                                                : unreadCount.toString(),
                                            textAlign: TextAlign.center,
                                            textWidthBasis:
                                                TextWidthBasis.parent,
                                            style: TextStyle(
                                              color: Colors.white,
                                              fontSize: 12,
                                              fontWeight: FontWeight.w500,
                                            ),
                                          )
                                        ],
                                      ),
                                    ),
                                  )
                                : null,
                            width: 18,
                            height: 18,
                            margin: EdgeInsets.only(right: 16),
                          )
                        ],
                      ),
                    )
                  ],
                ),
              ),
            )
          ],
        ),
      ),
    );
  }
}
