import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_friend_info.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_friend_operation_result.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_value_callback.dart';
import 'package:tencent_im_sdk_plugin/tencent_im_sdk_plugin.dart';
import 'package:tencent_im_sdk_plugin_example/common/colors.dart';
import 'package:tencent_im_sdk_plugin_example/provider/friend.dart';
import 'package:toast/toast.dart';

class Search extends StatefulWidget {
  @override
  State<StatefulWidget> createState() => SearchState();
}

class Input extends StatelessWidget {
  TextEditingController controller = new TextEditingController();
  addFriend(context, userID) async {
    if (userID == null || userID == '') {
      Toast.show("请输入正确的userID", context,
          duration: Toast.LENGTH_SHORT, gravity: Toast.CENTER);
      return;
    }
    V2TimValueCallback<V2TimFriendOperationResult> data =
        await tencent_im_sdk_plugin.v2TIMManager
            .getFriendshipManager()
            .addFriend(
              userID: userID,
              addType: 1,
            );
    if (data.code != 0) {
      Toast.show('${data.code}-${data.desc}', context,
          duration: Toast.LENGTH_SHORT, gravity: Toast.CENTER);
    } else {
      controller.clear();
      getFriendList(context);
      Navigator.pop(context);
    }
  }

  getFriendList(context) async {
    V2TimValueCallback<List<V2TimFriendInfo>> data = await tencent_im_sdk_plugin
        .v2TIMManager
        .getFriendshipManager()
        .getFriendList();
    if (data.code == 0 && data.data.length > 0) {
      Provider.of<FriendListModel>(context, listen: false)
          .setFriendList(data.data);
    }
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.all(10),
      height: 90,
      child: Row(
        children: [
          Expanded(
            child: TextField(
              controller: controller,
              decoration: InputDecoration(labelText: '请输入用户userID'),
              onSubmitted: (s) {
                addFriend(context, s);
              },
            ),
          )
        ],
      ),
    );
  }
}

class AddBtn extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Row(
      children: [
        Expanded(
          child: Container(
            padding: EdgeInsets.all(10),
            height: 60,
            child: FlatButton(
              child: Text('添加'),
              onPressed: () {},
              textColor: CommonColors.getWitheColor(),
              color: CommonColors.getThemeColor(),
            ),
          ),
        )
      ],
    );
  }
}

class SearchState extends State<Search> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('添加好友'),
        backgroundColor: CommonColors.getThemeColor(),
      ),
      body: Column(
        children: [
          Input(),
          Expanded(child: Container()),
          // AddBtn(),
        ],
      ),
    );
  }
}
