import 'package:flutter/material.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_user_full_info.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_value_callback.dart';
import 'package:tencent_im_sdk_plugin/tencent_im_sdk_plugin.dart';
import 'package:tencent_im_sdk_plugin_example/common/colors.dart';
import 'package:tencent_im_sdk_plugin_example/common/hexToColor.dart';
import 'package:tencent_im_sdk_plugin_example/pages/conversion/conversion.dart';
import 'package:tencent_im_sdk_plugin_example/pages/profile/component/addToBlackList.dart';
import 'package:tencent_im_sdk_plugin_example/pages/profile/component/listGap.dart';
import 'package:tencent_im_sdk_plugin_example/pages/profile/component/profilePanel.dart';
import 'package:tencent_im_sdk_plugin_example/pages/profile/component/userSign.dart';

class UserProfile extends StatefulWidget {
  UserProfile(this.userID);
  final String userID;
  @override
  State<StatefulWidget> createState() => UserProfileState();
}

class SendMessage extends StatelessWidget {
  SendMessage(this.userID);
  final String userID;
  @override
  Widget build(BuildContext context) {
    return Container(
      height: 50,
      child: Row(
        children: [
          Expanded(
            child: FlatButton(
              height: 44,
              color: CommonColors.getThemeColor(),
              onPressed: () {
                Navigator.push(
                  context,
                  new MaterialPageRoute(
                    builder: (context) => Conversion('c2c_${userID}'),
                  ),
                );
              },
              child: Text(
                '发送消息',
                style: TextStyle(
                  color: CommonColors.getWitheColor(),
                ),
              ),
            ),
          )
        ],
      ),
    );
  }
}

class DeleteFriend extends StatelessWidget {
  DeleteFriend(this.userID);
  final String userID;
  @override
  Widget build(BuildContext context) {
    return Container(
      height: 50,
      child: Row(
        children: [
          Expanded(
            child: FlatButton(
              height: 44,
              color: hexToColor('FA5151'),
              onPressed: () {},
              child: Text(
                '删除好友',
                style: TextStyle(
                  color: CommonColors.getWitheColor(),
                ),
              ),
            ),
          )
        ],
      ),
    );
  }
}

class HandleButtons extends StatelessWidget {
  HandleButtons(this.userID);
  final String userID;
  @override
  Widget build(BuildContext context) {
    return Container(
      height: 100,
      padding: EdgeInsets.only(
        left: 10,
        right: 10,
      ),
      child: Column(
        children: [
          SendMessage(userID),
          DeleteFriend(userID),
        ],
      ),
    );
  }
}

class UserProfileState extends State<UserProfile> {
  String userID;
  V2TimUserFullInfo userInfo;
  void initState() {
    userID = widget.userID;
    getUserInfo();
    super.initState();
  }

  getUserInfo() async {
    V2TimValueCallback<List<V2TimUserFullInfo>> data =
        await tencent_im_sdk_plugin.v2TIMManager
            .getUsersInfo(userIDList: [userID]);
    if (data.code == 0) {
      V2TimUserFullInfo info = data.data[0];

      setState(() {
        userInfo = info;
      });
    }
  }

  @override
  Widget build(Object context) {
    // print(userInfo.toJson());
    return Scaffold(
      appBar: AppBar(
        title: Text('用户资料'),
        backgroundColor: CommonColors.getThemeColor(),
      ),
      body: Column(
        children: [
          Expanded(
            child: Container(
              color: CommonColors.getGapColor(),
              child: Column(
                children: [
                  Expanded(
                    child: Column(
                      children: [
                        ProfilePanel(userInfo),
                        ListGap(),
                        UserSign(),
                        AddToBlackList(),
                      ],
                    ),
                  ),
                  HandleButtons(userID),
                ],
              ),
            ),
          )
        ],
      ),
    );
  }
}
