import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_callback.dart';

/// 提供了信令操作相关接口
///
///[addSignalingListener]添加信令监听
///
///[removeSignalingListener]移除信令监听
///
///[invite]邀请某个人
///
///[inviteInGroup]邀请群内的某些人
///
///[cancel]邀请方取消邀请
///
///[accept]接收方接收邀请
///
///[reject]接收方拒绝邀请
///
///[getSignalingInfo]获取信令信息
///
///[addInvitedSignaling]添加邀请信令（可以用于群离线推送消息触发的邀请信令）
///
/// {@category Manager}
///
class V2TIMSignalingManager {
  ///@nodoc
  MethodChannel _channel = null;

  ///@nodoc
  V2TIMSignalingManager(channel) {
    _channel = channel;
  }

  ///添加信令监听
  ///
  void addSignalingListener(Function listener) {
    _channel.invokeMethod("addSignalingListener", buildParam({}));
  }

  ///移除信令监听
  ///
  void removeSignalingListener(Function listener) {
    _channel.invokeMethod("removeSignalingListener", buildParam({}));
  }

  Future<V2TimCallback> invite({
    @required String invitee,
    String data,
    int timeout,
  }) async {
    return V2TimCallback.fromJson(
      formatJson(
        await _channel.invokeMethod(
          "invite",
          buildParam(
            {
              "invitee": invitee,
              "data": data,
              "timeout": timeout,
            },
          ),
        ),
      ),
    );
  }

  Future<V2TimCallback> inviteInGroup({
    @required String groupID,
    @required List<String> inviteeList,
    String data,
    int timeout,
  }) async {
    return V2TimCallback.fromJson(
      formatJson(
        await _channel.invokeMethod(
          "inviteInGroup",
          buildParam(
            {
              "groupID": groupID,
              "inviteeList": inviteeList,
              "data": data,
              "timeout": timeout,
            },
          ),
        ),
      ),
    );
  }

  Future<V2TimCallback> cancel({
    @required String inviteID,
    String data,
  }) async {
    return V2TimCallback.fromJson(
      formatJson(
        await _channel.invokeMethod(
          "cancel",
          buildParam(
            {
              "inviteID": inviteID,
              "data": data,
            },
          ),
        ),
      ),
    );
  }

  Future<V2TimCallback> accept({
    @required String inviteID,
    String data,
  }) async {
    return V2TimCallback.fromJson(
      formatJson(
        await _channel.invokeMethod(
          "accept",
          buildParam(
            {
              "inviteID": inviteID,
              "data": data,
            },
          ),
        ),
      ),
    );
  }

  Future<V2TimCallback> reject({
    @required String inviteID,
    String data,
  }) async {
    return V2TimCallback.fromJson(
      formatJson(
        await _channel.invokeMethod(
          "reject",
          buildParam(
            {
              "inviteID": inviteID,
              "data": data,
            },
          ),
        ),
      ),
    );
  }

  //TODO
  // Future<Map> getSignalingInfo(String msgID) async {
  //   return await _channel.invokeMethod(
  //       "getSignalingInfo",
  //       buildParam({
  //         "msg": msgID,
  //       }));
  // }

  // Future<Map> addInvitedSignaling(
  //   String inviteID,
  //   String groupID,
  //   List<String> inviteeList,
  //   String data,
  //   int timeout,
  //   int actionType,
  //   int businessID,
  // ) async {
  //   return await _channel.invokeMethod(
  //     "addInvitedSignaling",
  //     buildParam(
  //       {
  //         "inviteID": inviteID,
  //         "groupID": groupID,
  //         "inviteeList": inviteeList,
  //         "data": data,
  //         "timeout": timeout,
  //         "actionType": actionType,
  //         "businessID": businessID
  //       },
  //     ),
  //   );
  // }

  ///@nodoc
  Map buildParam(Map param) {
    param["TIMManagerName"] = "signalingManager";
    return param;
  }

  ///@nodoc
  formatJson(jsonSrc) {
    return json.decode(json.encode(jsonSrc));
  }
}
