import 'package:tencent_im_sdk_plugin/models/v2_tim_conversation.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_friend_application.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_friend_info.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_message.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_message_receipt.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_recv_c2c_custom_message.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_recv_group_custom_message.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_recv_group_text_message.dart';

import 'v2_tim_callback.dart';

import 'v2_tim_recv_c2c_text_message.dart';
import 'v2_tim_user_full_info.dart';

/// V2TimEventCallback
///
/// {@category Models}
///
class V2TimEventCallback<T> {
  String type;
  T data;
  V2TimEventCallback({this.type, this.data});

  factory V2TimEventCallback.fromJson(Map<String, dynamic> json) {
    if (T == V2TimUserFullInfo) {
      return V2TimEventCallback(
        type: json['type'],
        data: V2TimUserFullInfo.fromJson(json['data']) as T,
      );
    } else if (T == V2TimCallback) {
      return V2TimEventCallback(
        type: json['type'],
        data: V2TimCallback.fromJson(json['data']) as T,
      );
    } else if (T == V2TimRecvC2cTextMessage) {
      return V2TimEventCallback(
        type: json['type'],
        data: V2TimRecvC2cTextMessage.fromJson(json['data']) as T,
      );
    } else if (T == V2TimRecvC2cCustomMessage) {
      return V2TimEventCallback(
        type: json['type'],
        data: V2TimRecvC2cCustomMessage.fromJson(json['data']) as T,
      );
    } else if (T == V2TimRecvGroupTextMessage) {
      return V2TimEventCallback(
        type: json['type'],
        data: V2TimRecvGroupTextMessage.fromJson(json['data']) as T,
      );
    } else if (T == V2TimRecvGroupCustomMessage) {
      return V2TimEventCallback(
        type: json['type'],
        data: V2TimRecvGroupCustomMessage.fromJson(json['data']) as T,
      );
    } else if (T == V2TimMessage) {
      return V2TimEventCallback(
        type: json['type'],
        data: V2TimMessage.fromJson(json['data']) as T,
      );
    } else if (T.toString() == "List<V2TimMessageReceipt>") {
      return V2TimEventCallback(
        type: json['type'],
        data: (json['data'] as List)?.map((e) {
          return V2TimMessageReceipt.fromJson(e);
        })?.toList() as T,
      );
    } else if (T.toString() == 'List<V2TimFriendApplication>') {
      return V2TimEventCallback(
        type: json['type'],
        data: (json['data'] as List)?.map((e) {
          return V2TimFriendApplication.fromJson(e);
        })?.toList() as T,
      );
    } else if (T.toString() == 'List<String> ') {
      return V2TimEventCallback(
        type: json['type'],
        data: (json['data'] as List)?.map((e) {
          return e;
        })?.toList() as T,
      );
    } else if (T.toString() == 'List<V2TimFriendInfo>') {
      return V2TimEventCallback(
        type: json['type'],
        data: (json['data'] as List)?.map((e) {
          return V2TimFriendInfo.fromJson(e);
        })?.toList() as T,
      );
    } else if (T.toString() == 'List<V2TimConversation>') {
      return V2TimEventCallback(
        type: json['type'],
        data: (json['data'] as List)?.map((e) {
          return V2TimConversation.fromJson(e);
        })?.toList() as T,
      );
    }

    return V2TimEventCallback(
      type: json['type'],
      data: json['data'],
    );
  }
  toJson() {
    if (T == V2TimUserFullInfo) {
      return <String, dynamic>{
        "type": this.type,
        "data": (this.data as V2TimUserFullInfo).toJson()
      };
    } else if (T == V2TimCallback) {
      return <String, dynamic>{
        "type": this.type,
        "data": (this.data as V2TimCallback).toJson()
      };
    } else if (T == V2TimRecvC2cTextMessage) {
      return <String, dynamic>{
        "type": this.type,
        "data": (this.data as V2TimRecvC2cTextMessage).toJson()
      };
    } else if (T == V2TimRecvC2cCustomMessage) {
      return <String, dynamic>{
        "type": this.type,
        "data": (this.data as V2TimRecvC2cCustomMessage).toJson()
      };
    } else if (T == V2TimRecvGroupTextMessage) {
      return <String, dynamic>{
        "type": this.type,
        "data": (this.data as V2TimRecvGroupTextMessage).toJson()
      };
    } else if (T == V2TimRecvGroupCustomMessage) {
      return <String, dynamic>{
        "type": this.type,
        "data": (this.data as V2TimRecvGroupCustomMessage).toJson()
      };
    } else if (T == V2TimMessage) {
      return <String, dynamic>{
        "type": this.type,
        "data": (this.data as V2TimMessage).toJson()
      };
    } else if (T.toString() == "List<V2TimMessageReceipt>") {
      return <String, dynamic>{
        "type": this.type,
        "data": (this.data as List)
            .map((e) => (e as V2TimMessageReceipt).toJson())
            .toList(),
      };
    }
    return <String, dynamic>{
      "type": this.type,
      "data": this.data,
    };
  }
}
